@@ -307,6 +307,13 @@ fn replace_range() {
   assert_eq!(s, "Hello, 世界!");
 }
 
+#[test]
+#[should_panic]
+fn replace_range_backwards_range() {
+  let mut s = MyString::from("12345");
+  s.replace_range(3..0, "789");
+}
+
 #[test]
 #[should_panic]
 fn replace_range_char_boundary() {
